# Introduction

cs.video provides a Video object to refere to externally hosted FLV files. It uses FlowPlayer to show the video in the Plone site.

It also provides to additional views for Folder and Large Folders to show current folder's videos and also a video archive to show videos on folders inside current folder.

We used a pre-cs.video version templates and objects to do this in http://goiena.net/bideoak and now we are using cs.video in http://www.dantzan.com

In its template the video is shown using FlowPlayer, which is included and distributed with the product.

A macro called player is defined in the video_view template to be able to reuse the player in other templates such as portlets

- Code repository: http://code.codesyntax.com/private/cs.video
- Questions and comments to mlarreategi@codesyntax.com
- Report bugs to mlarreategi@codesyntax.com

# Changelog

## 2.1 (UNRELEASED)

## 2.0 (2012/10/17)

> - Plone 4 version [erral]

## 1.x (LONG TIME AGO)

> - Old versions... [erral]